@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -375,6 +374,8 @@ dlg_new_archive (FrWindow  *window,
 	gtk_widget_show (GTK_WIDGET (data->format_chooser));
 	gtk_box_pack_start (GTK_BOX (GET_WIDGET ("format_chooser_box")), GTK_WIDGET (data->format_chooser), TRUE, TRUE, 0);
 
+	gtk_widget_set_vexpand (GET_WIDGET ("extra_widget"), FALSE);
+
 	/* Set the signals handlers. */
 
 	/*g_signal_connect (G_OBJECT (data->dialog),
