@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -1370,8 +1369,8 @@ create_tmp_base_dir (const char *base_dir,
 
 	dir = g_build_filename (temp_dir, "/", dest_dir, NULL);
 	debug (DEBUG_INFO, "symlink %s --> %s\n", dir, base_dir);
-	if (symlink (base_dir, dir) != 0)
-		g_warning ("Could not create the symbolic link '%s', pointing to '%s'", dir, base_dir);
+	if (! symlink (base_dir, dir))
+		/* void */;
 
 	g_free (dir);
 	g_free (dest_dir);
@@ -1448,6 +1447,25 @@ fr_archive_set_add_is_stoppable_func (FrArchive     *archive,
 }
 
 
+static GList *
+convert_to_local_file_list (GList *file_list)
+{
+	GList *local_file_list = NULL;
+	GList *scan;
+
+	for (scan = file_list; scan; scan = scan->next) {
+		char *uri = scan->data;
+		char *local_filename;
+
+		local_filename = g_uri_unescape_string (uri, G_URI_RESERVED_CHARS_ALLOWED_IN_PATH);
+		if (local_filename != NULL)
+			local_file_list = g_list_prepend (local_file_list, local_filename);
+	}
+
+	return local_file_list;
+}
+
+
 static gboolean
 save_list_to_temp_file (GList   *file_list,
 		        char   **list_dir,
@@ -1572,6 +1590,7 @@ fr_archive_add (FrArchive     *archive,
 
 	fr_archive_stoppable (archive, fr_archive_add_is_stoppable (archive));
 
+	file_list = convert_to_local_file_list (file_list);
 	tmp_base_dir = g_strdup (base_dir);
 
 	if ((dest_dir != NULL) && (*dest_dir != '\0') && (strcmp (dest_dir, "/") != 0)) {
@@ -1588,9 +1607,10 @@ fr_archive_add (FrArchive     *archive,
 			char *filename = scan->data;
 			new_file_list = g_list_prepend (new_file_list, g_build_filename (rel_dest_dir, filename, NULL));
 		}
+		path_list_free (file_list);
 	}
 	else
-		new_file_list = path_list_dup (file_list);
+		new_file_list = file_list;
 
 	/* if the command cannot update,  get the list of files that are
 	 * newer than the ones in the archive. */
