@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <stdio.h>
@@ -324,15 +323,24 @@ fr_command_7z_add (FrCommand     *comm,
 		fr_process_add_arg_concat (comm->process, "-w", base_dir, NULL);
 	}
 
-	if (is_mime_type (comm->mime_type, "application/zip"))
+	if (is_mime_type (comm->mime_type, "application/zip")
+	    || is_mime_type (comm->mime_type, "application/x-cbz"))
+	{
 		fr_process_add_arg (comm->process, "-tzip");
+		fr_process_add_arg (comm->process, "-mem=AES128");
+	}
 
 	fr_process_add_arg (comm->process, "-bd");
 	fr_process_add_arg (comm->process, "-y");
 	fr_process_add_arg (comm->process, "-l");
 	add_password_arg (comm, comm->password, FALSE);
-	if ((comm->password != NULL) && (*comm->password != 0) && comm->encrypt_header)
+	if ((comm->password != NULL)
+	    && (*comm->password != 0)
+	    && comm->encrypt_header
+	    && fr_command_is_capable_of (comm, FR_COMMAND_CAN_ENCRYPT_HEADER))
+	{
 		fr_process_add_arg (comm->process, "-mhe=on");
+	}
 
 	/* fr_process_add_arg (comm->process, "-ms=off"); FIXME: solid mode off? */
 
@@ -517,6 +525,7 @@ const char *sevenz_mime_types[] = { "application/x-7z-compressed",
 				    /*"application/x-cbr",*/
 				    "application/x-cbz",
 				    "application/x-ms-dos-executable",
+				    "application/x-ms-wim",
 				    "application/x-rar",
 				    "application/zip",
 				    NULL };
@@ -531,25 +540,30 @@ fr_command_7z_get_mime_types (FrCommand *comm)
 
 FrCommandCap
 fr_command_7z_get_capabilities (FrCommand  *comm,
-				const char *mime_type)
+				const char *mime_type,
+				gboolean    check_command)
 {
 	FrCommandCap capabilities;
 
 	capabilities = FR_COMMAND_CAN_ARCHIVE_MANY_FILES;
-	if (! is_program_in_path ("7za") && ! is_program_in_path ("7zr") && ! is_program_in_path ("7z"))
+	if (! is_program_available ("7za", check_command) && ! is_program_available ("7zr", check_command) && ! is_program_available ("7z", check_command))
 		return capabilities;
 
 	if (is_mime_type (mime_type, "application/x-7z-compressed")) {
-		capabilities |= FR_COMMAND_CAN_READ_WRITE | FR_COMMAND_CAN_ENCRYPT | FR_COMMAND_CAN_ENCRYPT_HEADER | FR_COMMAND_CAN_CREATE_VOLUMES;
+		capabilities |= FR_COMMAND_CAN_READ_WRITE | FR_COMMAND_CAN_CREATE_VOLUMES;
+		if (is_program_available ("7z", check_command))
+			capabilities |= FR_COMMAND_CAN_ENCRYPT | FR_COMMAND_CAN_ENCRYPT_HEADER;
 	}
 	else if (is_mime_type (mime_type, "application/x-7z-compressed-tar")) {
-		capabilities |= FR_COMMAND_CAN_READ_WRITE | FR_COMMAND_CAN_ENCRYPT | FR_COMMAND_CAN_ENCRYPT_HEADER | FR_COMMAND_CAN_CREATE_VOLUMES;
+		capabilities |= FR_COMMAND_CAN_READ_WRITE;
+		if (is_program_available ("7z", check_command))
+			capabilities |= FR_COMMAND_CAN_ENCRYPT | FR_COMMAND_CAN_ENCRYPT_HEADER;
 	}
-	else if (is_program_in_path ("7z")) {
+	else if (is_program_available ("7z", check_command)) {
 		if (is_mime_type (mime_type, "application/x-rar")
 		    || is_mime_type (mime_type, "application/x-cbr"))
 		{
-			if (g_file_test ("/usr/lib/p7zip/Codecs/Rar29.so", G_FILE_TEST_EXISTS))
+			if (! check_command || g_file_test ("/usr/lib/p7zip/Codecs/Rar29.so", G_FILE_TEST_EXISTS))
 				capabilities |= FR_COMMAND_CAN_READ;
 		}
 		else
@@ -562,7 +576,7 @@ fr_command_7z_get_capabilities (FrCommand  *comm,
 			capabilities |= FR_COMMAND_CAN_WRITE | FR_COMMAND_CAN_ENCRYPT;
 		}
 	}
-	else if (is_program_in_path ("7za")) {
+	else if (is_program_available ("7za", check_command)) {
 		if (is_mime_type (mime_type, "application/vnd.ms-cab-compressed")
 		    || is_mime_type (mime_type, "application/zip"))
 		{
@@ -581,6 +595,19 @@ fr_command_7z_get_capabilities (FrCommand  *comm,
 }
 
 
+static const char *
+fr_command_7z_get_packages (FrCommand  *comm,
+			    const char *mime_type)
+{
+	if (is_mime_type (mime_type, "application/x-rar"))
+		return PACKAGES ("p7zip,p7zip-rar");
+	else if (is_mime_type (mime_type, "application/zip") || is_mime_type (mime_type, "application/vnd.ms-cab-compressed"))
+		return PACKAGES ("p7zip,p7zip-full");
+	else
+		return PACKAGES ("p7zip");
+}
+
+
 static void
 fr_command_7z_class_init (FrCommand7zClass *class)
 {
@@ -600,6 +627,7 @@ fr_command_7z_class_init (FrCommand7zClass *class)
 	afc->handle_error     = fr_command_7z_handle_error;
 	afc->get_mime_types   = fr_command_7z_get_mime_types;
 	afc->get_capabilities = fr_command_7z_get_capabilities;
+	afc->get_packages     = fr_command_7z_get_packages;
 }
 
 
