@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -388,24 +387,33 @@ fr_command_zip_get_mime_types (FrCommand *comm)
 
 FrCommandCap
 fr_command_zip_get_capabilities (FrCommand  *comm,
-			         const char *mime_type)
+			         const char *mime_type,
+				 gboolean    check_command)
 {
 	FrCommandCap capabilities;
 
 	capabilities = FR_COMMAND_CAN_ARCHIVE_MANY_FILES | FR_COMMAND_CAN_ENCRYPT;
-	if (is_program_in_path ("zip")) {
+	if (is_program_available ("zip", check_command)) {
 		if (strcmp (mime_type, "application/x-ms-dos-executable") == 0)
 			capabilities |= FR_COMMAND_CAN_READ;
 		else
 			capabilities |= FR_COMMAND_CAN_READ_WRITE;
 	}
-	else if (is_program_in_path ("unzip"))
+	else if (is_program_available ("unzip", check_command))
 		capabilities |= FR_COMMAND_CAN_READ;
 
 	return capabilities;
 }
 
 
+static const char *
+fr_command_zip_get_packages (FrCommand  *comm,
+			     const char *mime_type)
+{
+	return PACKAGES ("zip,unzip");
+}
+
+
 static void
 fr_command_zip_class_init (FrCommandZipClass *class)
 {
@@ -425,6 +433,7 @@ fr_command_zip_class_init (FrCommandZipClass *class)
 	afc->handle_error     = fr_command_zip_handle_error;
 	afc->get_mime_types   = fr_command_zip_get_mime_types;
 	afc->get_capabilities = fr_command_zip_get_capabilities;
+	afc->get_packages     = fr_command_zip_get_packages;
 }
 
 
