@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -110,6 +109,7 @@ FrMimeTypeDescription mime_type_desc[] = {
 	{ "application/x-lzma-compressed-tar",  ".tar.lzma", N_("Tar compressed with lzma (.tar.lzma)"), 0 },
 	{ "application/x-lzop",                 ".lzo",      NULL, 0 },
 	{ "application/x-lzop-compressed-tar",  ".tar.lzo",  N_("Tar compressed with lzop (.tar.lzo)"), 0 },
+	{ "application/x-ms-wim",               ".wim",      N_("Windows Imaging Format (.wim)"), 0 },
 	{ "application/x-rar",                  ".rar",      N_("Rar (.rar)"), 0 },
 	{ "application/x-rpm",                  ".rpm",      NULL, 0 },
 	{ "application/x-rzip",                 ".rz",       NULL, 0 },
@@ -153,6 +153,7 @@ FrExtensionType file_ext_type[] = {
 	{ ".rpm", "application/x-rpm" },
 	{ ".rz", "application/x-rzip" },
 	{ ".sit", "application/x-stuffit" },
+	{ ".swm", "application/x-ms-wim" },
 	{ ".tar", "application/x-tar" },
 	{ ".tar.bz", "application/x-bzip-compressed-tar" },
 	{ ".tar.bz2", "application/x-bzip-compressed-tar" },
@@ -173,6 +174,7 @@ FrExtensionType file_ext_type[] = {
 	{ ".tzma", "application/x-lzma-compressed-tar" },
 	{ ".tzo", "application/x-lzop-compressed-tar" },
 	{ ".war", "application/x-war" },
+	{ ".wim", "application/x-ms-wim" },
 	{ ".xz", "application/x-xz" },
 	{ ".z", "application/x-gzip" },
 	{ ".Z", "application/x-compress" },
@@ -824,29 +826,41 @@ fr_restore_session (EggSMClient *client)
 	}
 }
 
+
+static void
+migrate_options_directory (void)
+{
+	char *old_directory_path;
+	GFile *old_directory;
+	GFile *new_directory;
+
+	old_directory_path = get_home_relative_path (".gnome2/file-roller/options");
+	old_directory = g_file_new_for_path (old_directory_path);
+	new_directory = get_user_config_subdirectory (ADD_FOLDER_OPTIONS_DIR, FALSE);
+	if (g_file_query_exists (old_directory, NULL) && ! g_file_query_exists (new_directory, NULL)) {
+		GFile *parent;
+
+		parent = g_file_get_parent (new_directory);
+		if (make_directory_tree (parent, 0700, NULL))
+			g_file_move (old_directory, new_directory, 0, NULL, NULL, NULL, NULL);
+
+		g_object_unref (parent);
+	}
+
+	g_object_unref (new_directory);
+	g_object_unref (old_directory);
+	g_free (old_directory_path);
+}
+
+
 static void
 prepare_app (void)
 {
-	char *uri;
-	char *extract_to_path = NULL;
-	char *add_to_path = NULL;
+	char        *extract_to_uri = NULL;
+	char        *add_to_uri = NULL;
 	EggSMClient *client = NULL;
 
-	/* create the config dir if necessary. */
-
-	uri = get_home_relative_uri (RC_DIR);
-
-	if (uri_is_file (uri)) { /* before the GConf port this was a file, now it's folder. */
-		GFile *file;
-
-		file = g_file_new_for_uri (uri);
-		g_file_delete (file, NULL, NULL);
-		g_object_unref (file);
-	}
-
-	ensure_dir_exists (uri, 0700, NULL);
-	g_free (uri);
-
+	migrate_options_directory ();
 	register_commands ();
 	compute_supported_archive_types ();
 
@@ -864,10 +878,10 @@ prepare_app (void)
 	}
 
 	if (extract_to != NULL)
-		extract_to_path = get_uri_from_command_line (extract_to);
+		extract_to_uri = get_uri_from_command_line (extract_to);
 
 	if (add_to != NULL)
-		add_to_path = get_uri_from_command_line (add_to);
+		add_to_uri = get_uri_from_command_line (add_to);
 
 	if ((add_to != NULL) || (add == 1)) { /* Add files to an archive */
 		GtkWidget   *window;
@@ -884,16 +898,17 @@ prepare_app (void)
 		file_list = g_list_reverse (file_list);
 
 		fr_window_new_batch (FR_WINDOW (window));
-		fr_window_set_batch__add (FR_WINDOW (window), add_to_path, file_list);
+		fr_window_set_batch__add (FR_WINDOW (window), add_to_uri, file_list);
 		fr_window_append_batch_action (FR_WINDOW (window),
 					       FR_BATCH_ACTION_QUIT,
 					       NULL,
 					       NULL);
 		fr_window_start_batch (FR_WINDOW (window));
 	}
-	else if ((extract_to != NULL)
-		  || (extract == 1)
-		  || (extract_here == 1)) { /* Extract all archives. */
+	else if ((extract_to != NULL) || (extract == 1) || (extract_here == 1)) {
+
+		/* Extract all archives. */
+
 		GtkWidget  *window;
 		const char *archive;
 		int         i = 0;
@@ -913,7 +928,7 @@ prepare_app (void)
 			else
 				fr_window_set_batch__extract (FR_WINDOW (window),
 							      archive_uri,
-							      extract_to_path);
+							      extract_to_uri);
 			g_free (archive_uri);
 		}
 		fr_window_append_batch_action (FR_WINDOW (window),
@@ -943,6 +958,6 @@ prepare_app (void)
 		}
 	}
 
-	g_free (add_to_path);
-	g_free (extract_to_path);
+	g_free (add_to_uri);
+	g_free (extract_to_uri);
 }
