@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef MAIN_H
@@ -70,10 +69,15 @@ extern int save_type[];             /* File types that can be saved. */
 extern int open_type[];             /* File types that can be opened. */
 extern int create_type[];           /* File types that can be created. */
 
-GType        get_command_type_from_mime_type (const char    *mime_type,
-				 	      FrCommandCaps  requested_capabilities);
-const char * get_mime_type_from_extension    (const char    *ext);
-const char * get_archive_filename_extension  (const char    *uri);
-int          get_mime_type_index             (const char    *mime_type);
-
+GType        get_command_type_from_mime_type         (const char    *mime_type,
+						      FrCommandCaps  requested_capabilities);
+GType        get_preferred_command_for_mime_type     (const char    *mime_type,
+						      FrCommandCaps  requested_capabilities);
+void         update_registered_commands_capabilities (void);
+const char * get_mime_type_from_extension            (const char    *ext);
+const char * get_archive_filename_extension          (const char    *uri);
+int          get_mime_type_index                     (const char    *mime_type);
+void         sort_mime_types_by_extension            (int           *a);
+void         sort_mime_types_by_description          (int           *a);
+		                              
 #endif /* MAIN_H */
